/**
* \file
*
* \brief The definition of EPD GPIO pins
*
* Copyright (c) 2012-2014 Pervasive Displays Inc. All rights reserved.
*
*  Authors: Pervasive Displays Inc.
*
*  Redistribution and use in source and binary forms, with or without
*  modification, are permitted provided that the following conditions
*  are met:
*
*  1. Redistributions of source code must retain the above copyright
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in
*     the documentation and/or other materials provided with the
*     distribution.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
*  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
*  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
*  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
*  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
*  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
*  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
*  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
*  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#include "Pervasive_Displays_small_EPD.h"

#ifndef DISPLAY_HARDWARE_GPIO_H_INCLUDED
#define DISPLAY_HARDWARE_GPIO_H_INCLUDED

#define	_BV(bit)   (1 << (bit)) /**< left shift 1 bit */
#define	_HIGH      1            /**< signal high */
#define	_LOW       !_HIGH       /**< signal low */

#define	config_gpio_dir_o(Port,Pin)  Chip_GPIO_SetPortDIROutput(LPC_GPIO, (Port), (Pin))
#define	config_gpio_dir_i(Port,Pin)  Chip_GPIO_SetPortDIRInput(LPC_GPIO, (Port), (Pin))
#define	set_gpio_high(Port,Pin)      Chip_GPIO_SetPortOutHigh(LPC_GPIO, (Port), (Pin))
#define	set_gpio_low(Port,Pin)       Chip_GPIO_SetPortOutLow(LPC_GPIO, (Port), (Pin))
#define	input_get(Port,Pin)          (Chip_GPIO_ReadValue(LPC_GPIO, (Port)) & (Pin))

/******************************************************************************
* GPIO Defines
*****************************************************************************/

/*
 *   Description  | Expansion | OEM Base Board | LPC4088 OEM Board
 *   --------------------------------------------------------------
 *   SPI SCK            3          GPIO29         P5.2
 *   SPI MOSI           4          GPIO32         P5.0
 *   SPI MISO           5          GPIO31         P5.1
 *   CS EPD             6          GPIO69         P2.14
 *   Busy               7          GPIO25         P4.23
 *   Border Ctrl        8          GPIO24         P4.22
 *   I2C SCL            9          I2C_SCL        P0.28
 *   I2C SDA           10          I2C_SDA        P0.27
 *   CS Flash          11          GPIO42         P1.18
 *   Reset             12          GPIO72         P2.21
 *   Power             13          GPIO37         P0.23
 *   Discharge         14          GPIO38         P0.24
 *
 */

//#define Temper_PIN              BIT4
//#define Temper_PORT             P1
#define SPICLK_PIN              (1<<2)
#define SPICLK_PORT             5
#define EPD_BUSY_PIN            (1<<23)
#define EPD_BUSY_PORT           4
//#define PWM_PIN                 BIT1
//#define PWM_PORT                P2
#define EPD_RST_PIN             (1<<21)
#define EPD_RST_PORT            2
#define EPD_PANELON_PIN         (1<<23)
#define EPD_PANELON_PORT        0
#define EPD_DISCHARGE_PIN       (1<<24)
#define EPD_DISCHARGE_PORT      0
#define EPD_BORDER_PIN          (1<<22)
#define EPD_BORDER_PORT         4
#define SPIMISO_PIN             (1<<1)
#define SPIMISO_PORT            5
#define SPIMOSI_PIN             (1<<0)
#define SPIMOSI_PORT            5
#define Flash_CS_PIN            (1<<18)
#define Flash_CS_PORT           1
//#define	Flash_CS_PORT_SEL	    (SEL (Flash_CS_PORT))
//#define	Flash_CS_PORT_SEL2		(SEL2(Flash_CS_PORT))
#define EPD_CS_PIN              (1<<14)
#define EPD_CS_PORT             2
//#define	CS_PORT_SEL		        (SEL (EPD_CS_PORT))
//#define	CS_PORT_SEL2		    (SEL2(EPD_CS_PORT))

bool EPD_IsBusy(void);
void EPD_cs_high (void);
void EPD_cs_low (void);
void EPD_flash_cs_high(void);
void EPD_flash_cs_low (void);
void EPD_rst_high (void);
void EPD_rst_low (void);
void EPD_discharge_high (void);
void EPD_discharge_low (void);
void EPD_Vcc_turn_off (void);
void EPD_Vcc_turn_on (void);
void EPD_border_high(void);
void EPD_border_low (void);
void EPD_pwm_low (void);
void EPD_pwm_high(void);
void SPIMISO_low(void);
void SPIMOSI_low(void);
void SPICLK_low(void);
void EPD_initialize_gpio(void);

#endif	//DISPLAY_HARDWARE_GPIO_H_INCLUDED
