
#include "board.h"

#include "Pervasive_Displays_small_EPD.h"
#include "image_data.h"

#include "lm75a.h"


/*****************************************************************************
 * Private types/enumerations/variables
 ****************************************************************************/

#define TICKRATE_HZ1 (10)	/* 10 ticks per second */

static volatile uint32_t msticks = 0;

/*****************************************************************************
 * Public types/enumerations/variables
 ****************************************************************************/

/*****************************************************************************
 * Private functions
 ****************************************************************************/

static void wait(int secdelay) {
	int destTime = msticks + 1000*secdelay;
	while(msticks < destTime) {
		__WFI();
	}
}

/*****************************************************************************
 * Public functions
 ****************************************************************************/

/**
 * @brief	Handle interrupt from SysTick timer
 * @return	Nothing
 */
void SysTick_Handler(void)
{
	msticks += (1000/TICKRATE_HZ1);
}

/**
 * @brief	main routine for systick example
 * @return	Function should not exit.
 */
int main(void)
{
	/* Generic Initialization */
	SystemCoreClockUpdate();
	Board_Init();

	/* Enable and setup SysTick Timer at a periodic rate */
	SysTick_Config(SystemCoreClock / TICKRATE_HZ1);

	EPD_display_init();

	/* LEDs toggle in interrupt handlers */
    while(1) {
    	Board_LED_Set(0, true);
    	EPD_display_from_pointer(EPD_270, NULL, (uint8_t*)&image_array_270_ea);
    	Board_LED_Set(0, false);
        wait(5);
    	Board_LED_Set(0, true);
        EPD_display_from_pointer(EPD_270, NULL, (uint8_t*)&image_array_270_text);
    	Board_LED_Set(0, false);
        wait(5);
    	Board_LED_Set(0, true);
        EPD_display_from_pointer(EPD_270, NULL, (uint8_t*)&image_array_270_1);
    	Board_LED_Set(0, false);
        wait(5);
    	Board_LED_Set(0, true);
        EPD_display_from_pointer(EPD_270, NULL, (uint8_t*)&image_array_270_2);
    	Board_LED_Set(0, false);
        wait(5);
    }
}


