/*****************************************************************************
 *
 *   Copyright(C) 2011, Embedded Artists AB
 *   All rights reserved.
 *
 ******************************************************************************
 * Software that is described herein is for illustrative purposes only
 * which provides customers with programming information regarding the
 * products. This software is supplied "AS IS" without any warranties.
 * Embedded Artists AB assumes no responsibility or liability for the
 * use of the software, conveys no license or title under any patent,
 * copyright, or mask work right to the product. Embedded Artists AB
 * reserves the right to make changes in the software without
 * notification. Embedded Artists AB also make no representation or
 * warranty that such application will be suitable for the specified
 * use without further testing or modification.
 *****************************************************************************/

/*
 * NOTE: I2C must have been initialized before calling any functions in this
 * file.
 */

/******************************************************************************
 * Includes
 *****************************************************************************/

#include "board.h"


/******************************************************************************
 * Defines and typedefs
 *****************************************************************************/

#define I2C_PORT (I2C0)

//#define LM75A_I2C_ADDR    (0x48)  // On the OEM Base Board
#define LM75A_I2C_ADDR    (0x49)  // On the ePaper display adapter

#define LM75A_CMD_TEMP 0x00

#define SPEED_100KHZ         100000
#define SPEED_400KHZ         400000


/******************************************************************************
 * External global variables
 *****************************************************************************/

/******************************************************************************
 * Local variables
 *****************************************************************************/


/******************************************************************************
 * Local Functions
 *****************************************************************************/
static Status I2CWrite(uint32_t addr, uint8_t* buf, uint32_t len) 
{
	I2C_XFER_T i2cData;

	i2cData.slaveAddr = addr;
	i2cData.txBuff = buf;
	i2cData.txSz = len;
	i2cData.rxBuff = NULL;
	i2cData.rxSz = 0;

  return Chip_I2C_MasterTransfer(I2C_PORT, &i2cData);
}

static Status I2CRead(uint32_t addr, uint8_t* buf, uint32_t len) 
{
	I2C_XFER_T i2cData;

	i2cData.slaveAddr = addr;
	i2cData.txBuff = NULL;
	i2cData.txSz = 0;
	i2cData.rxBuff = buf;
	i2cData.rxSz = len;

  return Chip_I2C_MasterTransfer(I2C_PORT, &i2cData);
}

/******************************************************************************
 * Public Functions
 *****************************************************************************/

/******************************************************************************
 *
 * Description:
 *    Initialize the LM75 Driver
 *
 *****************************************************************************/
void lm75a_init (void)
{
	Board_I2C_Init(I2C_PORT);
	Chip_I2C_Init(I2C_PORT);
	Chip_I2C_SetClockRate(I2C_PORT, SPEED_100KHZ);

	// Set polling mode
	NVIC_DisableIRQ(I2C0_IRQn);
	Chip_I2C_SetMasterEventHandler(I2C_PORT, Chip_I2C_EventHandlerPolling);
}

/******************************************************************************
 *
 * Description:
 *    Read the temperature
 *
 * Params: None
 *
 * Returns:
 *   The measured temperature x 100, i.e. 26.50 degrees returned as 2650
 *
 *****************************************************************************/
int32_t lm75a_readTemp(void)
{
    uint8_t temp[2];
    int16_t t = 0;

    I2CWrite(LM75A_I2C_ADDR, LM75A_CMD_TEMP, 1);
    I2CRead(LM75A_I2C_ADDR, temp, 2);

    /* 11 MSB bits used. Celcius is calculated as Temp data * 1/8 */
    t = ((temp[0] << 8) | (temp[1]));

    return ((t * 100) >> 8);

}


